@@ -2,12 +2,14 @@ from django.contrib.auth import get_user_model
 from django.contrib.auth.hashers import check_password
 from django.contrib.auth.tokens import default_token_generator
 from django.core import mail
+from django.core.cache import cache
 from django.core.urlresolvers import reverse
 from django.utils.encoding import force_bytes
 from django.utils.http import urlsafe_base64_encode
 from mock import patch
 from rest_framework import status
 from rest_framework.authtoken.models import Token
+from rest_framework.test import APIRequestFactory
 
 from user_management.api import views
 from user_management.models.tests.factories import UserFactory
@@ -22,6 +24,9 @@ TEST_SERVER = 'http://testserver'
 class GetTokenTest(APIRequestTestCase):
     view_class = views.GetToken
 
+    def tearDown(self):
+        cache.clear()
+
     def test_post(self):
         username = 'Test@example.com'
         password = 'myepicstrongpassword'
@@ -60,6 +65,21 @@ class GetTokenTest(APIRequestTestCase):
         response = self.view_class.as_view()(request)
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
+    @patch('rest_framework.throttling.ScopedRateThrottle.THROTTLE_RATES', new={
+        'logins': '1/minute',
+    })
+    def test_user_auth_throttle(self):
+        auth_url = reverse('user_management_api:auth')
+        expected_status = status.HTTP_429_TOO_MANY_REQUESTS
+
+        request = APIRequestFactory().get(auth_url)
+
+        response = self.view_class.as_view()(request)
+        self.assertNotEqual(response.status_code, expected_status)
+
+        response = self.view_class.as_view()(request)
+        self.assertEqual(response.status_code, expected_status)
+
 
 class TestRegisterView(APIRequestTestCase):
     view_class = views.UserRegister
@@ -154,6 +174,9 @@ class TestRegisterView(APIRequestTestCase):
 class TestPasswordResetEmail(APIRequestTestCase):
     view_class = views.PasswordResetEmail
 
+    def tearDown(self):
+        cache.clear()
+
     def test_existent_email(self):
         email = 'exists@example.com'
         user = UserFactory.create(email=email)
@@ -229,6 +252,21 @@ class TestPasswordResetEmail(APIRequestTestCase):
             expected_post_options,
         )
 
+    @patch('rest_framework.throttling.ScopedRateThrottle.THROTTLE_RATES', new={
+        'passwords': '1/minute',
+    })
+    def test_user_password_reset_throttle(self):
+        auth_url = reverse('user_management_api:password_reset')
+        expected_status = status.HTTP_429_TOO_MANY_REQUESTS
+
+        request = APIRequestFactory().get(auth_url)
+
+        response = self.view_class.as_view()(request)
+        self.assertNotEqual(response.status_code, expected_status)
+
+        response = self.view_class.as_view()(request)
+        self.assertEqual(response.status_code, expected_status)
+
 
 class TestPasswordReset(APIRequestTestCase):
     view_class = views.PasswordReset
